@@ -5,7 +5,7 @@ from typing import List, Union
 from pathlib import Path
 
 
-__version__ = "2022.6.22.1"
+__version__ = "2022.6.23.1"
 log_format = logging.Formatter(
     "[%(asctime)s] %(filename)s/%(lineno)s/%(funcName)s/%(levelname)s: %(message)s"
 )
@@ -23,7 +23,7 @@ if len(logger.handlers) == 0:
     logger.addHandler(console_handler)
 
 
-def clean_handler():
+def clean_handler(close_console_handler: bool = False):
     """清理日志handler，关闭所有FileHandler实例，StreamHandler实例只保留一个"""
     _first_console = False
     logger.debug(f"开始清理日志句柄：{logger.handlers}")
@@ -34,15 +34,22 @@ def clean_handler():
             _handler.close()
             logger.removeHandler(_handler)
         elif isinstance(_handler, logging.StreamHandler):
-            # 对于StreamHandler实例，仅保留一个，防止越积越多
-            if _first_console is False:
-                _first_console = True
-                logger.debug(f"保留：{_handler}")
-            else:
+            # 如果有指定新的console_handler，则关闭老的
+            if close_console_handler:
                 logger.debug(f"关闭：{_handler}")
                 _handler.flush()
                 _handler.close()
                 logger.removeHandler(_handler)
+            else:
+                # 对于StreamHandler实例，仅保留一个，防止越积越多
+                if _first_console is False:
+                    _first_console = True
+                    logger.debug(f"保留：{_handler}")
+                else:
+                    logger.debug(f"关闭：{_handler}")
+                    _handler.flush()
+                    _handler.close()
+                    logger.removeHandler(_handler)
         else:
             logger.debug(f"忽略：{_handler}")
 
@@ -74,6 +81,7 @@ def configure_logger(
         logging.NOTSET,
         logging.DEBUG,
         logging.INFO,
+        logging.WARN,
         logging.WARNING,
         logging.ERROR,
         logging.FATAL,
@@ -82,6 +90,13 @@ def configure_logger(
     else:
         raise ValueError(f"level参数非法：{level}")
 
+    # 检查是否指定了新的console_handler处理器
+    new_console_handler = False
+    for handler in handlers:
+        if type(handler) == logging.StreamHandler:
+            new_console_handler = True
+            break
+
     # 重置日志处理器输出格式
     if fmt and isinstance(fmt, logging.Formatter):
         for handler in logger.handlers:
@@ -96,7 +111,7 @@ def configure_logger(
     # 必须放置在设置已有Handler日志级别之后，因为已有的Handler可能被别处引用
     # 如果放置在最前面会导致在别处引用的handler日志级别无法受level参数控制
     if not append:
-        clean_handler()
+        clean_handler(new_console_handler)
 
     # 收集已有的 FileHandler 处理器输出文件路径列表
     log_file_list = []
